import { createWebHashHistory, createRouter } from 'vue-router'

import Layout from '../layout/index.vue'
import HomeView from '../views/home/index.vue'
import AssetsHome from '../views/assets/home.vue'
import PlanningHome from '../views/planning/home.vue'
import PersonalHome from '../views/personal/home.vue'
import HouseWorkbench from '../views/house/workbench/index.vue'
import Consignor from '../views/house/workbench/consignor.vue'
import Certificate from '../views/house/workbench/certificate.vue'
import BaseInfo from '../views/house/workbench/baseInfo.vue'
import Assumption from '../views/house/workbench/assumption.vue'
import EntityInfo from '../views/house/workbench/entityInfo.vue'
import FolderChild from '../views/house/folder/child.vue'
import FolderParent from '../views/house/folder/parent.vue'
import Folder from '../views/house/folder/index.vue'

const routes = [
  {
    path:'/',
    redirect:'/home/index'
  },
  {
    path:'/home',
    redirect:'/home/index'
  },
  {
    path:'/home/house',
    redirect:'/home/house/parent'
  },
  {
    path:'/home/houseWorkbench',
    redirect:'/home/house/parent'
  },
  {
    path: '/home',
    component: Layout,
    name: 'home',
    meta: {
      title: '首页'
    },
    children: [
      {
        path: 'index',
        component: HomeView,
        name: 'homeIndex',
      },
      {
        path: 'assets',
        component: AssetsHome,
        name: 'assetsIndex',
        meta: {
          title: '资产工作台'
        },
      },
      {
        path: 'planning',
        component: PlanningHome,
        name: 'planningIndex',
        meta: {
          title: '土地工作台'
        },
      },
      {
        path: 'house',
        component: Folder,
        name: 'folder',
        meta: {
          title: '房地产工作台'
        },
        children: [
          {
            path: 'parent',
            component: FolderParent,
            name: 'FolderParent',
            meta: {
              title: '项目'
            },
          },
          {
            path: 'folder',
            component: FolderChild,
            name: 'folderChild',
            meta: {
              title: '文件夹'
            },
          }

        ]
      },
      {
        path: 'houseWorkbench',
        component: HouseWorkbench,
        name: 'houseWorkbench',
        meta: {
          title:'房地产项目'
        },
        children: [
          {
            path: 'consignor',
            component: Consignor,
            name: 'consignor',
            meta: {
              title:'委托人信息'
            },
          },
          {
            path: 'certificate',
            component: Certificate,
            name: 'certificate',
            meta: {
              title:'权属资料'
            },
          },
          {
            path: 'baseInfo',
            component: BaseInfo,
            name: 'baseInfo',
            meta: {
              title:'项目基本信息'
            },
          },
          {
            path: 'assumption',
            component: Assumption,
            name: 'assumption',
            meta: {
              title:'假设条件'
            },
          },
          {
            path: 'entityInfo',
            component: EntityInfo,
            name: 'entityInfo',
            meta: {
              title:'实物状况'
            },
          }
        ]
      }

    ],
    
  },
]

const router = createRouter({
  history: createWebHashHistory(),
  routes,
})

export default router